@@ -1,10 +1,12 @@
 #!/bin/bash
 # Find and enable/disable wireless devices
 
-state=`. /etc/acpi/wireless.sh`
+. /usr/share/acpi-support/state-funcs
 
-if [ "$state" = "0" ]; then
-	toshset -bluetooth off
-else
+toggleAllWirelessStates;
+
+if isAnyWirelessPoweredOn; then
 	toshset -bluetooth on
+else
+	toshset -bluetooth off
 fi
